Index: LightsManager.cpp
===================================================================
--- LightsManager.cpp	(revision 28031)
+++ LightsManager.cpp	(working copy)
@@ -15,6 +15,11 @@
 #include "CommonMetrics.h"
 #include "Style.h"
 
+bool prevstate = false;
+extern int serial_handle;
+char zero[4] = "0\r\n";
+char one[4] = "1\r\n";
+
 const RString DEFAULT_LIGHTS_DRIVER = "SystemMessage,Export";
 static Preference<RString> g_sLightsDriver( "LightsDriver", "" ); // "" == DEFAULT_LIGHTS_DRIVER
 Preference<float>	g_fLightsFalloffSeconds( "LightsFalloffSeconds", 0.1f );
@@ -205,6 +210,7 @@
 		m_fTestAutoCycleCurrentIndex = fmodf( m_fTestAutoCycleCurrentIndex, NUM_CabinetLight*100 );
 	}
 
+	bool anded = false;
 	switch( m_LightsMode )
 	{
 	case LIGHTSMODE_ATTRACT:
@@ -292,13 +298,27 @@
 	case LIGHTSMODE_DEMONSTRATION:
 	case LIGHTSMODE_GAMEPLAY:
 		FOREACH_CabinetLight( cl )
+		{
 			m_LightsState.m_bCabinetLights[cl] = m_fSecsLeftInCabinetLightBlink[cl] > 0;
+			anded |= m_LightsState.m_bCabinetLights[cl];
+		}
+		if(anded == prevstate)
+			break;
+		if(anded) {
+			write(serial_handle, one, 1);
+			//printf("ON\n");
+		} else {
+			write(serial_handle, zero, 1);
+			//printf("OFF\n");
+		}
+		prevstate = anded;
 		break;
 	case LIGHTSMODE_STAGE:
 	case LIGHTSMODE_ALL_CLEARED:
 		{
 			FOREACH_CabinetLight( cl )
 				m_LightsState.m_bCabinetLights[cl] = true;
+			write(serial_handle, one, 1);
 		}
 		break;
 	case LIGHTSMODE_TEST_AUTO_CYCLE:
Index: StepMania.cpp
===================================================================
--- StepMania.cpp	(revision 28031)
+++ StepMania.cpp	(working copy)
@@ -71,6 +71,12 @@
 #include "GameLoop.h"
 #include "SpecialFiles.h"
 
+#include <termios.h>
+#include <fcntl.h>
+#include <unistd.h>
+#include <sys/signal.h>
+#include <sys/types.h>
+
 #if defined(XBOX)
 #include "Archutils/Xbox/VirtualMemory.h"
 #endif
@@ -79,6 +85,8 @@
 #include <windows.h>
 #endif
 
+int serial_handle;
+
 static Preference<bool> g_bAllowMultipleInstances( "AllowMultipleInstances", false );
 
 
@@ -916,6 +924,10 @@
 
 static LocalizedString COULDNT_OPEN_LOADING_WINDOW( "StepMania", "Couldn't open any loading windows." );
 
+void signal_handler_IO(int status) {
+	
+}
+
 int main(int argc, char* argv[])
 {
 	RageThreadRegister thread( "Main thread" );
@@ -982,6 +994,33 @@
 
 	WriteLogHeader();
 
+	/* try to open the serial port */
+	struct termios oldtio, newtio;
+	struct sigaction saio;
+	saio.sa_handler = signal_handler_IO;
+	sigemptyset(&saio.sa_mask);
+	saio.sa_flags = 0;
+	saio.sa_restorer = NULL;
+	sigaction(SIGIO, &saio, NULL);
+
+	serial_handle = open( "/dev/ttyUSB0", O_RDWR | O_NOCTTY | O_NONBLOCK);
+	if(serial_handle > 0) {
+		printf("Opened serial port successfully.\n");
+		fcntl(serial_handle, F_SETFL, FASYNC);
+		tcgetattr(serial_handle, &oldtio); // save current port settings.
+		// set new port settings for canonical input processing.
+		newtio.c_cflag = B115200 | CS8 ; // 8N1, no hardware flow control, no DTR/DTS or DCD
+		newtio.c_iflag = IGNPAR;
+		newtio.c_oflag = 0;
+		newtio.c_lflag = 0;       //ICANON;
+		newtio.c_cc[VMIN]=1;
+		newtio.c_cc[VTIME]=0;
+		tcflush(serial_handle, TCIFLUSH);
+		tcsetattr(serial_handle,TCSANOW,&newtio);
+	} else {
+		printf("*********THIS WILL FAIL, COULDN'T OPEN SERIAL DEVICE**********\n");
+	}
+
 	/* Set up alternative filesystem trees. */
 	if( PREFSMAN->m_sAdditionalFolders.Get() != "" )
 	{
